==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/LinearReferenceDetails.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LINEARREFERENCEEVENT_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LINEARREFERENCEEVENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONDIRECTIONCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FLOWCODE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "linearrefuom",
    "linearreferenceevent",
    "inspectiondirectioncode",
    "flowcode"
})
@XmlRootElement(name = "LinearReferenceDetails")
public class LinearReferenceDetails {

    @XmlElement(name = "LINEARREFUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linearrefuom;
    @XmlElement(name = "LINEARREFERENCEEVENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEEVENT_Type linearreferenceevent;
    @XmlElement(name = "INSPECTIONDIRECTIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inspectiondirectioncode;
    @XmlElement(name = "FLOWCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String flowcode;

    /**
     * Gets the value of the linearrefuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Sets the value of the linearrefuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Gets the value of the linearreferenceevent property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public LINEARREFERENCEEVENT_Type getLINEARREFERENCEEVENT() {
        return linearreferenceevent;
    }

    /**
     * Sets the value of the linearreferenceevent property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public void setLINEARREFERENCEEVENT(LINEARREFERENCEEVENT_Type value) {
        this.linearreferenceevent = value;
    }

    /**
     * Gets the value of the inspectiondirectioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONDIRECTIONCODE() {
        return inspectiondirectioncode;
    }

    /**
     * Sets the value of the inspectiondirectioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONDIRECTIONCODE(String value) {
        this.inspectiondirectioncode = value;
    }

    /**
     * Gets the value of the flowcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLOWCODE() {
        return flowcode;
    }

    /**
     * Sets the value of the flowcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLOWCODE(String value) {
        this.flowcode = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/LinearReferenceDetails.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LINEARREFERENCEEVENT_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFERENCEEVENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONDIRECTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOWCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "linearrefuom",
    "linearreferenceevent",
    "inspectiondirectioncode",
    "flowcode"
})
@XmlRootElement(name = "LinearReferenceDetails")
public class LinearReferenceDetails {

    @XmlElement(name = "LINEARREFUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linearrefuom;
    @XmlElement(name = "LINEARREFERENCEEVENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEEVENT_Type linearreferenceevent;
    @XmlElement(name = "INSPECTIONDIRECTIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inspectiondirectioncode;
    @XmlElement(name = "FLOWCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String flowcode;

    /**
     * Gets the value of the linearrefuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Sets the value of the linearrefuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Gets the value of the linearreferenceevent property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public LINEARREFERENCEEVENT_Type getLINEARREFERENCEEVENT() {
        return linearreferenceevent;
    }

    /**
     * Sets the value of the linearreferenceevent property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEEVENT_Type }
     *     
     */
    public void setLINEARREFERENCEEVENT(LINEARREFERENCEEVENT_Type value) {
        this.linearreferenceevent = value;
    }

    /**
     * Gets the value of the inspectiondirectioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONDIRECTIONCODE() {
        return inspectiondirectioncode;
    }

    /**
     * Sets the value of the inspectiondirectioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONDIRECTIONCODE(String value) {
        this.inspectiondirectioncode = value;
    }

    /**
     * Gets the value of the flowcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLOWCODE() {
        return flowcode;
    }

    /**
     * Sets the value of the flowcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLOWCODE(String value) {
        this.flowcode = value;
    }

}
